# maysics
本库用于科学计算和快速建模

maysics主要包括十一个模块：<br/>
1、calc 封装了常见的算符算子、函数、积分方法，辅助数学运算；<br/>
2、equa 封装了部分方程求解方法；<br/>
3、explain 用于评估和解释模型；<br/>
4、graph 用于图论分析；<br/>
5、digital 用于数字图像、序列处理;<br/>
6、models 封装了几种常用的模型、算法以便快速构建数理模型；<br/>
7、prep 用于数据预处理；<br/>
8、stats 用于统计分析；<br/>
9、time 用于处理时间数据；<br/>
10、trans 封装了常用的坐标转换及其他数学变换；<br/>
11、utils 是额外工具箱。<br/>


This package is used for scientific calculating and fast modeling

maysics includes eleven modules:<br/>
1. "calc" packaes common operatoes, functions and integration method;<br/>
2. "equa" packages some equation solving operation;<br/>
3. "explain" is used for estimating and explaining models;<br/>
4. "graph" is used for graph theory analysis;<br/>
5. "digital" is used for digital image, sequence process;<br/>
6. "models" packages several coommon models and algorithms for fast modeling;<br/>
7. "prep" is used for data preproccessing;<br/>
8. "stats" is uesd for statistical analysis;<br/>
9. "time" is used for processing time data;<br/>
10. "trans" packages common coordinate transformations and other mathematical transformations;<br/>
11. "utils" is extra Utils.